import { select, 
        csv, 
        scaleLinear, 
        extent, 
        scaleBand,
        axisLeft,
        axisBottom,
        format } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Horsepower versus Weight'
  const xValue = d => d.horsepower;
  const xAxisLabel = 'Horsepower';
  const yValue = d => d.weight;
  const yAxisLabel = 'Weight';
  const circleRadius = 8;
  const margin = { top: 50, left: 100, right: 50, bottom: 55};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  // console.log(xScale.domain());
    
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
  
  // const yAxis = axisLeft(yScale);

  // The whole thing is contained in group g, as we need to have identical margins. 
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  // yAxis(g.append('g'));
  
  // A shortened version of appending a new group element that corresponds to the yAxis. Method "call" takes in the yAxis that we have just created.
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
    
  // Here is the yAxis. 
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(5);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('transform', `rotate(-90)`)
  	.attr('class', 'axis-label')
  	.attr('x', -innerHeight/2)
  	.attr('y', -50)
  	.attr('fill', 'black')
  	.style('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  // Here is the xAxis. 
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', innerWidth/2)
  	.attr('y', 35)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
	g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('x', 275)
  	.attr('y', -15)
  	.text(title)
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then(data => {
  data.forEach(d => {
  	d.mpg = +d.mpg;
    d.cylinders = +d.cylinders;
    d.displacement = +d.displacement;
    d.horsepower = +d.horsepower;
    d.weight = +d.weight;
    d.acceleration = +d.acceleration;
    d.year = +d.year;
  });
	render(data);
});